@@ -2,10 +2,11 @@
     warnings,
     missing_docs,
     clippy::pedantic,
-    clippy::missing_inline_in_public_items
+    clippy::missing_inline_in_public_items,
+    clippy::dbg_macro
 )]
 #![forbid(unsafe_code)]
-#![allow(clippy::non_ascii_literal, clippy::inline_always, unknown_lints)]
+#![allow(clippy::non_ascii_literal, clippy::inline_always)]
 #![deny(clippy::semicolon_if_nothing_returned)]
 #![cfg_attr(nightly, feature(str_internals, unboxed_closures, fn_traits))]
 #![doc(test(attr(deny(warnings), forbid(unsafe_code))))]
